==> mongodb-src-r3.6.23.tar.gz: mongodb-src-r3.6.23/src/mongo/db/keys_collection_client_sharded.cpp <==

/**
 *    Copyright (C) 2018-present MongoDB, Inc.
 *
 *    This program is free software: you can redistribute it and/or modify
 *    it under the terms of the Server Side Public License, version 1,
 *    as published by MongoDB, Inc.
 *
 *    This program is distributed in the hope that it will be useful,
 *    but WITHOUT ANY WARRANTY; without even the implied warranty of
 *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *    Server Side Public License for more details.
 *
 *    You should have received a copy of the Server Side Public License
 *    along with this program. If not, see
 *    <http://www.mongodb.com/licensing/server-side-public-license>.
 *
 *    As a special exception, the copyright holders give permission to link the
 *    code of portions of this program with the OpenSSL library under certain
 *    conditions as described in each individual source file and distribute
 *    linked combinations including the program with the OpenSSL library. You
 *    must comply with the Server Side Public License in all respects for
 *    all of the code used other than as permitted herein. If you modify file(s)
 *    with this exception, you may extend this exception to your version of the
 *    file(s), but you are not obligated to do so. If you do not wish to do so,
 *    delete this exception statement from your version. If you delete this
 *    exception statement from all source files in the program, then also delete
 *    it in the license file.
 */

#include "mongo/platform/basic.h"

#include "mongo/db/keys_collection_client_sharded.h"
#include "mongo/s/catalog/sharding_catalog_client.h"

namespace mongo {

namespace {}  // namespace

KeysCollectionClientSharded::KeysCollectionClientSharded(ShardingCatalogClient* client)
    : _catalogClient(client) {}


StatusWith<std::vector<KeysCollectionDocument>> KeysCollectionClientSharded::getNewKeys(
    OperationContext* opCtx, StringData purpose, const LogicalTime& newerThanThis) {

    return _catalogClient->getNewKeys(
        opCtx, purpose, newerThanThis, repl::ReadConcernLevel::kMajorityReadConcern);
}

Status KeysCollectionClientSharded::insertNewKey(OperationContext* opCtx, const BSONObj& doc) {
    return _catalogClient->insertConfigDocument(
        opCtx, KeysCollectionDocument::ConfigNS, doc, ShardingCatalogClient::kMajorityWriteConcern);
}
}  // namespace mongo

==> mongodb-src-r5.2.0.tar.gz: mongodb-src-r5.2.0/src/mongo/db/keys_collection_client_sharded.cpp <==
/**
 *    Copyright (C) 2018-present MongoDB, Inc.
 *
 *    This program is free software: you can redistribute it and/or modify
 *    it under the terms of the Server Side Public License, version 1,
 *    as published by MongoDB, Inc.
 *
 *    This program is distributed in the hope that it will be useful,
 *    but WITHOUT ANY WARRANTY; without even the implied warranty of
 *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *    Server Side Public License for more details.
 *
 *    You should have received a copy of the Server Side Public License
 *    along with this program. If not, see
 *    <http://www.mongodb.com/licensing/server-side-public-license>.
 *
 *    As a special exception, the copyright holders give permission to link the
 *    code of portions of this program with the OpenSSL library under certain
 *    conditions as described in each individual source file and distribute
 *    linked combinations including the program with the OpenSSL library. You
 *    must comply with the Server Side Public License in all respects for
 *    all of the code used other than as permitted herein. If you modify file(s)
 *    with this exception, you may extend this exception to your version of the
 *    file(s), but you are not obligated to do so. If you do not wish to do so,
 *    delete this exception statement from your version. If you delete this
 *    exception statement from all source files in the program, then also delete
 *    it in the license file.
 */

#include "mongo/platform/basic.h"

#include "mongo/db/keys_collection_client_sharded.h"

#include "mongo/s/catalog/sharding_catalog_client.h"

namespace mongo {

KeysCollectionClientSharded::KeysCollectionClientSharded(ShardingCatalogClient* client)
    : _catalogClient(client) {}


StatusWith<std::vector<KeysCollectionDocument>> KeysCollectionClientSharded::getNewInternalKeys(
    OperationContext* opCtx,
    StringData purpose,
    const LogicalTime& newerThanThis,
    bool useMajority) {

    return _catalogClient->getNewKeys(
        opCtx, purpose, newerThanThis, repl::ReadConcernLevel::kMajorityReadConcern);
}

StatusWith<std::vector<ExternalKeysCollectionDocument>>
KeysCollectionClientSharded::getAllExternalKeys(OperationContext* opCtx, StringData purpose) {
    return std::vector<ExternalKeysCollectionDocument>{};
}

Status KeysCollectionClientSharded::insertNewKey(OperationContext* opCtx, const BSONObj& doc) {
    return _catalogClient->insertConfigDocument(opCtx,
                                                NamespaceString::kKeysCollectionNamespace,
                                                doc,
                                                ShardingCatalogClient::kMajorityWriteConcern);
}

}  // namespace mongo
